/* --------------------------------------------------------
Code for jquery.pushmenu()

version: 0.0.1
author: Thomas Schwarz
email: info@thomasschwarz-websolutions.de
website: https://www.thomasschwarz-websolutions.de
License: MIT
  _____ _                      ___     _                       ___  __ 
 |_   _| |_  ___ _ __  __ _ __/ __| __| |___ __ ____ _ _ _ ___/ _ \/ / 
   | | | ' \/ _ \ '  \/ _` (_-<__ \/ _| ' \ V  V / _` | '_|_ /\_, / _ \
   |_| |_||_\___/_|_|_\__,_/__/___/\__|_||_\_/\_/\__,_|_| /__| /_/\___/
----------------------------------------------------------*/
(function ( $ ) {

    /*
    * _checkPossibility
    * check if all Elements exists
    */
    var _checkPossibility = function(me, options) {

      var isPossible = true;

      // Check for selected list.
      if ( typeof(me) === 'undefined' && me === null ) {
        isPossible = false;
      }

      return isPossible;
    }

    /*
    * _createStructure
    * create HTML structure
    */
    var _createStructure = function(me, options) {

      // ID's for the new generated Elements.
      var pushmenuId = 'pushmenu',
          toggleButtonId = 'pushmenu-toggle';

      // holder for the Toggle-Button.
      var toggleButton =
      '<a href="#toggle" id="'+ toggleButtonId +'">' +
        '<span class="pushmenu-toggle-bar"></span>' +
        '<span class="pushmenu-toggle-bar"></span>' +
        '<span class="pushmenu-toggle-bar"></span>' +
      '</a>';

      // holder for the HTML structure.
      var structure =
      '<div id="'+ pushmenuId +'">' +
        '<div id="pushmenu-title">'+ options.title +'</div>'+
          me[0].outerHTML +
        '</div>' +
      '</div>';

      // Append new Toggle-Button and pushMenu to body.
      document.body.innerHTML = document.body.innerHTML + toggleButton + structure;

      // Set new Toggle-Button to settings/options.
      options.button = document.getElementById(toggleButtonId);

      // Return appended pushMenu element.
      return document.getElementById(pushmenuId);
    }

    /*
    * _setStyle
    * set styles and classes for element
    */
    var _setStyle = function(me, options) {

      // Get list of pushMenu.
      var list = me.childNodes[1];

      // Remove all ID's and classes.
      list.id = '';
      list.className = '';

      // Add class to list for basic style.
      list.classList.add('pushmenu-list');

      // Set modified list to me.
      me.childNodes[1] = list;

      // Add class for position.
      if ( options.position === 'right' ) {
        me.classList.add('pushmenu-right');
      }

      // Set css styles.
      me.style.color = options.color;
      me.style.backgroundColor = options.backgroundColor;

      // Set color for links in given list.
      var anchors = document.querySelectorAll('#pushmenu .pushmenu-list a');
      if ( anchors.length ) {
        for (var i = 0; i < anchors.length; i++) {
          anchors[i].style.color = options.color;
        }
      }

      // Return modified element.
      return me;
    }

    /*
    * _toggleMenu
    * toggle the menu
    */
    var _toggleMenu = function(me, options) {

      // Toggle class for showing menu.
      function makeToggle() {
        me.classList.toggle('pushmenu-open');
      }

      // Check if button exists.
      if ( options.button ) {

        // Add event listener on click.
        document.getElementById(options.button.id).addEventListener('click', makeToggle, false);

      } else {
        console.log('-- jQuery.pushMenu(): Toggle Button not exists. --')
      }

      // Return modified element.
      return me;
    }

    /*
    * _breakpoint
    * set breakpoint for show up the Menu
    */
    var _breakpoint = function(me, options) {

      // Check for breakpoint and show Toggle Button.
      function checkForBreakpoint() {

        // Check for breakpoint and window width
        if (options.breakpoint >= window.innerWidth) {
          document.getElementById(options.button.id).style.display = 'block';
        } else {
          me.classList = '';
          document.getElementById(options.button.id).style.display = 'none';
        }
      }

      // Call function for window init.
      checkForBreakpoint();

      // Add event listener on window resize.
      window.addEventListener('resize', checkForBreakpoint, false);

      // Return modified element.
      return me;
    }

    /*
    * pushMenu
    * plugin definition
    */
    $.fn.pushMenu = function( options ) {

        var me = this;

        // Set default options.
        // - button -> is not rewritable
        var settings = $.extend({
            button: document.getElementById('pushmenu-toggle'),
            title: 'Navigation',
            color: "#fff",
            backgroundColor: "#333",
            position: 'left',
            breakpoint: false
        }, options );

        // Check possibility.
        if ( ! _checkPossibility( me, settings ) ) {
          console.log('-- jQuery.pushMenu(): not possible! Check Settings! --');
          return false;
        }

        // Create structure.
        me = _createStructure( me, settings );

        // Set style options.
        me = _setStyle( me, settings );

        // Check if breakpoint is set.
        if ( settings.breakpoint ) {
            // Set given breakpoint.
            me = _breakpoint( me, settings );
        }

        // Init toggle button.
        me = _toggleMenu( me, settings );

        return me;
    };

}( jQuery ));
